@@ -8,6 +8,7 @@ import warnings
 from collections import defaultdict, Counter, OrderedDict, namedtuple
 from decimal import Decimal
 from fractions import Fraction
+from rich import print
 # import upsetplot
 
 
@@ -516,3 +517,22 @@ def diff3(arg1, arg2, arg3, show_graph=0, p=0):
         pprint(sorted_returned_list, compact=True, width=120)
     else:
         return sorted_returned_list
+
+
+def list_inheritable(p=0):
+    import builtins, re
+    x = sorted([i for i in dir(builtins) if not re.search('.*Error|Warning|__|_', i)], key=len)
+    inheritable = []
+    non_inheritable = []
+    for i in x:
+        try:
+            A = type('A', (eval(i),), {})
+            inheritable.append(i)
+        except:
+            non_inheritable.append(i)
+
+    returned_dict = {'inheritable': inheritable, 'non_inheritable': non_inheritable}
+    if p == 1:
+        pprint(returned_dict, compact=True, width=120)
+    else:
+        return returned_dict
\ No newline at end of file
